@@ -181,7 +181,7 @@ class TweetDownloader:  # pylint: disable=too-few-public-methods
                         # contain NUL characters that cause hickups in PostgreSQL
                         results = json.loads(
                             response.text
-                            .replace("\\u0000", "\u2400")
+                            .replace("\\u0000", "\\u2400")
                         )
                     except json.decoder.JSONDecodeError as exception:
                         raise ApiResponseError(response.text) from exception
